@@ -21,14 +21,14 @@
 set -e
 set -x
 
-requires nbdkit --exit-with-parent --version
-requires stat --version
+requires $NBDKIT --exit-with-parent --version
+requires $STAT --version
 
 file=copy-nbd-to-stdout.file
 cleanup_fn rm -f $file
 
-$VG nbdcopy -- [ nbdkit --exit-with-parent -v pattern size=10M ] - > $file
-if [ "$(stat -c %s $file)" -ne $(( 10 * 1024 * 1024 )) ]; then
+$VG nbdcopy -- [ $NBDKIT --exit-with-parent -v pattern size=10M ] - > $file
+if [ "$($STAT -c %s $file)" -ne $(( 10 * 1024 * 1024 )) ]; then
     echo "$0: incorrect amount of data copied"
     exit 1
 fi
