@@ -1,5 +1,5 @@
 /* NBD client library in userspace.
- * Copyright (C) 2020-2022 Red Hat Inc.
+ * Copyright Red Hat
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -634,7 +634,7 @@ fill_dst_range_with_zeroes (struct command *command)
   char *data;
   size_t data_size;
 
-  if (destination_is_zero)
+  if (target_is_zero)
     goto free_and_return;
 
   /* Try efficient zeroing. */
