@@ -286,16 +286,16 @@ let print_fndecl ?wrap ?closure_style name args optargs ret =
   pr "\n    LIBNBD_ATTRIBUTE_NONNULL (%s);\n" (String.concat ", " nns)
 
 let rec print_cbarg_list ?(wrap = false) ?maxcol ?types ?(parens = true)
-          cbargs =
+          ?(noconst = false) cbargs =
   if parens then pr "(";
   if wrap then
     pr_wrap ?maxcol ','
-      (fun () -> print_cbarg_list' ?types cbargs)
+      (fun () -> print_cbarg_list' ?types noconst cbargs)
   else
-    print_cbarg_list' ?types cbargs;
+    print_cbarg_list' ?types noconst cbargs;
   if parens then pr ")"
 
-and print_cbarg_list' ?(types = true) cbargs =
+and print_cbarg_list' ?(types = true) noconst cbargs =
   if types then pr "void *";
   pr "user_data";
 
@@ -316,6 +316,7 @@ and print_cbarg_list' ?(types = true) cbargs =
       | CBArrayAndLen _ -> assert false
       | CBBytesIn (n, len) ->
          if types then pr "const void *";
+         if noconst then pr "(void *)";
          pr "%s, " n;
          if types then pr "size_t ";
          pr "%s" len
@@ -331,6 +332,7 @@ and print_cbarg_list' ?(types = true) cbargs =
       | CBMutable arg -> assert false
       | CBString n ->
          if types then pr "const char *";
+         if noconst then pr "(char *)";
          pr "%s" n
       | CBUInt n ->
          if types then pr "unsigned ";
