@@ -130,7 +130,7 @@ main (int argc, char *argv[])
     { "can",                required_argument, NULL, CAN_OPTION },
     { "cannot",             required_argument, NULL, CANNOT_OPTION },
     { "can-not",            required_argument, NULL, CANNOT_OPTION },
-    { "cant",               required_argument, NULL, CANNOT_OPTION },
+    { "can""t",             required_argument, NULL, CANNOT_OPTION },
     { "color",              no_argument,       NULL, COLOUR_OPTION },
     { "colors",             no_argument,       NULL, COLOUR_OPTION },
     { "colour",             no_argument,       NULL, COLOUR_OPTION },
@@ -144,15 +144,15 @@ main (int argc, char *argv[])
     { "has",                required_argument, NULL, CAN_OPTION },
     { "hasnot",             required_argument, NULL, CANNOT_OPTION },
     { "has-not",            required_argument, NULL, CANNOT_OPTION },
-    { "hasnt",              required_argument, NULL, CANNOT_OPTION },
+    { "hasn""t",            required_argument, NULL, CANNOT_OPTION },
     { "have",               required_argument, NULL, CAN_OPTION },
-    { "havent",             required_argument, NULL, CANNOT_OPTION },
+    { "haven""t",           required_argument, NULL, CANNOT_OPTION },
     { "havenot",            required_argument, NULL, CANNOT_OPTION },
     { "have-not",           required_argument, NULL, CANNOT_OPTION },
     { "is",                 required_argument, NULL, CAN_OPTION },
     { "isnot",              required_argument, NULL, CANNOT_OPTION },
     { "is-not",             required_argument, NULL, CANNOT_OPTION },
-    { "isnt",               required_argument, NULL, CANNOT_OPTION },
+    { "isn""t",             required_argument, NULL, CANNOT_OPTION },
     { "json",               no_argument,       NULL, JSON_OPTION },
     { "list",               no_argument,       NULL, 'L' },
     { "long-options",       no_argument,       NULL, LONG_OPTIONS },
