@@ -28,6 +28,7 @@
 
 #include <stdio.h>
 #include <stdbool.h>
+#include <stdint.h>
 #include <string.h>
 #include <netdb.h>
 #include <sys/types.h>
@@ -116,6 +117,7 @@ struct nbd_handle {
   char *tls_certificates;       /* Certs dir, NULL = use default path */
   bool tls_verify_peer;         /* Verify the peer certificate. */
   char *tls_username;           /* Username, NULL = use current username */
+  char *tls_hostname;           /* TLS hostname */
   char *tls_psk_file;           /* PSK filename, NULL = no PSK */
 
   /* Extended headers. */
@@ -419,7 +421,7 @@ struct execvpe {
   /* Note: "const_string_vector" is not a good type for "sh_argv" below. Even if
    * we reserved enough space in a "const_string_vector",
    * const_string_vector_append() would still not be async-signal-safe, due to
-   * the underlying const_string_vector_insert() calling assert().
+   * the underlying const_string_vector_insert() calling assert.
    */
   char **sh_argv;
   size_t num_sh_args;
