@@ -63,6 +63,13 @@ struct uri_query {
 
 DEFINE_VECTOR_TYPE (uri_query_list, struct uri_query);
 
+static void
+free_uri_query (struct uri_query q)
+{
+  free (q.name);
+  free (q.value);
+}
+
 /* Parse the query_raw substring of a URI into a list of decoded queries.
  * Return 0 on success or -1 on error.
  */
@@ -154,7 +161,7 @@ error:
 }
 
 /* Similar to nbdkit_parse_bool */
-int
+static int
 parse_bool (const char *param, const char *value)
 {
   if (!strcmp (value, "1") ||
@@ -446,10 +453,10 @@ nbd_unlocked_aio_connect_uri (struct nbd_handle *h, const char *raw_uri)
   case ssh: {                   /* SSH */
     char port_str[32];
     const char *ssh_command[] = {
-      "ssh", "-p", port_str, uri->server,
+      "ssh", "-p", port_str, "--", uri->server,
       "nc",
-      NULL,                     /* [5] "-U" or "localhost" */
-      NULL,                     /* [6] socket or "10809" */
+      NULL,                     /* [6] "-U" or "localhost" */
+      NULL,                     /* [7] socket or "10809" */
       NULL,
     };
 
@@ -461,12 +468,12 @@ nbd_unlocked_aio_connect_uri (struct nbd_handle *h, const char *raw_uri)
               "%d", uri->port > 0 ? uri->port : 22);
 
     if (unixsocket) {
-      ssh_command[5] = "-U";
-      ssh_command[6] = unixsocket;
+      ssh_command[6] = "-U";
+      ssh_command[7] = unixsocket;
     }
     else {
-      ssh_command[5] = "localhost";
-      ssh_command[6] = "10809"; /* XXX provide a way to configure this */
+      ssh_command[6] = "localhost";
+      ssh_command[7] = "10809"; /* XXX provide a way to configure this */
     }
 
     if (nbd_unlocked_aio_connect_command (h, (char **) ssh_command) == -1)
@@ -477,11 +484,8 @@ nbd_unlocked_aio_connect_uri (struct nbd_handle *h, const char *raw_uri)
   ret = 0;
 
 cleanup:
-  for (i = 0; i < queries.len; ++i) {
-    free (queries.ptr[i].name);
-    free (queries.ptr[i].value);
-  }
-  free (queries.ptr);
+  uri_query_list_iter (&queries, free_uri_query);
+  uri_query_list_reset (&queries);
   xmlFreeURI (uri);
   return ret;
 }
