@@ -18,13 +18,12 @@
 
 # Test AIO random load.
 
-. ../tests/functions.sh
-
+source ./functions.sh
 set -e
 set -x
 
-requires nbdkit --tls-verify-peer -U - null --run 'exit 0'
+requires $NBDKIT --tls-verify-peer -U - null --run 'exit 0'
 
-nbdkit -U - --tls=require --tls-verify-peer --tls-psk=keys.psk \
-       memory size=64M \
-       --run '$VG ./aio-parallel-load-tls $unixsocket'
+$NBDKIT -U - --tls=require --tls-verify-peer --tls-psk=keys.psk \
+        memory size=64M \
+        --run '$VG ./aio-parallel-load-tls $unixsocket'
