@@ -18,5 +18,9 @@
 
 # Test AIO random load.
 
-nbdkit -U - memory size=64M \
-       --run './aio-parallel-load $unixsocket'
+source ./functions.sh
+set -e
+set -x
+
+$NBDKIT -U - memory size=64M \
+        --run './aio-parallel-load $unixsocket'
