@@ -59,7 +59,7 @@ main (int argc, char *argv[])
     exit (EXIT_FAILURE);
   }
   if (pid == 0) {
-    execlp ("nbdkit",
+    execlp (NBDKIT,
             "nbdkit", "-fv", "-p", port_str, "-P", PIDFILE,
             "--exit-with-parent", "null", NULL);
     perror ("nbdkit");
